pygeodesy.booleans.BooleanFHP

Package pygeodesy :: Module booleans :: Class BooleanFHP |
[frames] | no frames]

# Class BooleanFHP

      object --+
               |
    named._Named --+
                   |
      _CompositeBase --+
                       |
           _CompositeFHP --+
                           |
              object --+   |
                       |   |
            _BooleanBase --+
                           |
                          BooleanFHP

Composite class providing boolean operations between two composites using Forster-Hormann-Popa's C++ implementation, transcoded to pure Python.

The supported operations between (composite) polygon A and B are:

- C = A & B or A &= B, intersection of A and B
- C = A + B or A += B, sum of A and B clips
- C = A | B or A |= B, union of A and B
- A == B or A != B, equivalent A and B clips
- A.isequalTo(B, eps), equivalent within tolerance

See Also: Methods `__eq__` and `isequalTo`, function clipFHP4 and class BooleanGH.

Instance Methods
__init__(self, lls, raiser=False, eps=2.220446049250313e-16, **name) New BooleanFHP operand for boolean operation. |
__isub__(self, other) Not implemented. |
__rsub__(self, other) Not implemented. |
__sub__(self, other) Not implemented. |
Inherited from `_CompositeBase`: `__contains__`, `__eq__`, `__iter__`, `__len__`, `__ne__`, `__repr__`, `__str__`, `clipids`, `isequalTo`, `toLatLon` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `_BooleanBase`: `__add__`, `__and__`, `__iadd__`, `__iand__`, `__ior__`, `__or__`, `__radd__`, `__rand__`, `__ror__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_CompositeBase`: `eps`, `raiser` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, lls, raiser=False, eps=2.220446049250313e-16, **name) (Constructor) |
New BooleanFHP operand for boolean operation. Arguments: `lls` - The polygon points and clips (iterable of LatLonFHPs, ClipFHP4Tuples or other `LatLon`s). `raiser` - If `True`, throw ClipError exceptions (`bool`). `esp` - Tolerance for eliminating null edges (`degrees`, same units as the `lls` coordinates). `name` - Optional `name=NN` (`str`). Overrides: object.__init__